@@ -26,12 +26,12 @@ MAPPING_VALUE = {
 
 @attr.dataclass
 class AksesSarprasTransport:
-    pekerjaan: SarprasTransport
-    pertanian: SarprasTransport
-    sekolah: SarprasTransport
-    berobat: SarprasTransport
-    ibadah: SarprasTransport
-    rekreasi: SarprasTransport
+    pekerjaan: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
+    pertanian: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
+    sekolah: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
+    berobat: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
+    ibadah: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
+    rekreasi: SarprasTransport = attr.field(default=attr.Factory(SarprasTransport))
 
     def todict(self) -> Dict[str, Dict[str, str]]:
         data: Dict[str, Dict[str, str]] = dict()
@@ -46,3 +46,8 @@ class AksesSarprasTransport:
         for name, args in MAPPING_VALUE.items():
             data[name] = SarprasTransport.from_cols(ws, row, *args)
         return data
+
+    def save(self, ws: Worksheet, row: int):
+        for name, args in MAPPING_VALUE.items():
+            sarpras: SarprasTransport = getattr(self, name)
+            sarpras.save(ws, row, *args)
