@@ -1,5 +1,7 @@
 import attr
 import cattr
+from enum import Enum
+from openpyxl import Workbook
 from openpyxl.worksheet.worksheet import Worksheet
 from typing import Any, Dict, Optional, Tuple
 
@@ -41,7 +43,7 @@ class DataKeluarga:
     alamat: str
     nomor_hp: str
     telepon_rumah: str
-    anggota_keluarga: str
+    anggota_keluarga: Optional[str] = None
     tempat_tinggal: TempatTinggal
     tempat_tinggal_comment: Optional[str] = None
     status_lahan: StatusLahan
@@ -85,6 +87,9 @@ class DataKeluarga:
     penerima_program_pemerintah: BantuanPemerintah
     pengeluaran_bulanan: str = "0"
 
+    def __str__(self):
+        return f"{self.nama} ({self.no_kk})"
+
     def __attrs_post_init__(self) -> None:
         if self.no_kk in (None, "None"):
             raise ValueError("Nomor KK harus diisi")
@@ -173,3 +178,22 @@ class DataKeluarga:
             }
         )
         return clean_data
+
+    def save(self, ws: Worksheet, row: int):
+        MAPPING = dict(MAPPING_COLS)
+        MAPPING.pop("penerima_program_pemerintah")
+        for name, col in MAPPING.items():
+            value = getattr(self, name)
+            if value is None:
+                continue
+            if isinstance(value, Enum):
+                value = str(value)
+            ws[f"{col}{row}"] = value
+        # Luas
+        ws[f"L{row}"] = self.luas.lantai
+        ws[f"M{row}"] = self.luas.lahan
+        self.akses_pendidikan.save(ws, row)
+        self.akses_fasilitas_kesehatan.save(ws, row)
+        self.akses_tenaga_kesehatan.save(ws, row)
+        self.akses_sarpras_transport.save(ws, row)
+        ws[f"EL{row}"] = str(self.penerima_program_pemerintah)
