@@ -1,5 +1,5 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 MAPPING = {
     "Ledeng/perpipaan berbayar/air isi ulang/kemasan": "1",
@@ -8,6 +8,7 @@ MAPPING = {
     "Sungai/danau/embung": "4",
     "Tadah air hujan": "5",
     "Lainnya": "other",
+    "Ledeng/perpipaan berbayar/air isi ulang/kemasan": "1",
 }
 
 
@@ -20,3 +21,4 @@ class SumberAirMinum(Enum):
     LAINNYA = "other"
 
     from_str = classmethod(make_str_to_enum(MAPPING, "1"))
+    __str__ = make_dunder_str(MAPPING)
