@@ -1,5 +1,5 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 
 MAPPING = {
@@ -21,3 +21,4 @@ class TempatTinggal(Enum):
     LAINNYA = "other"
 
     from_str = classmethod(make_str_to_enum(MAPPING, "1"))
+    __str__ = make_dunder_str(MAPPING)
