@@ -1,11 +1,12 @@
 from enum import Enum
-from sdgs_tools.dashboard.utils import make_str_to_enum
+from sdgs_tools.dashboard.utils import make_str_to_enum, make_dunder_str
 
 MAPPING = {
     "Ya": "1",
     "Tidak": "2",
     "Mudah": "1",
     "Susah": "2",
+    "Sulit": "2",
 }
 
 
@@ -17,3 +18,4 @@ class YaTidak(Enum):
         return self.value == self.YA
 
     from_str = classmethod(make_str_to_enum(MAPPING, "2"))
+    __str__ = make_dunder_str(MAPPING)
