@@ -42,3 +42,24 @@ class SarprasTransport:
             "biaya": ws[f"{b}{row}"].value,
             "kemudahan": ws[f"{k}{row}"].value,
         }
+
+    def save(
+        self,
+        ws: Worksheet,
+        row: int,
+        j: str,
+        t: str,
+        w: str,
+        b: str,
+        k: str,
+    ):
+        if self.jenis is not None:
+            ws[f"{j}{row}"] = self.jenis.value
+        if self.transport_umum is not None:
+            ws[f"{t}{row}"] = self.transport_umum.value
+        if self.waktu is not None:
+            ws[f"{w}{row}"] = self.waktu
+        if self.biaya is not None:
+            ws[f"{b}{row}"] = self.biaya
+        if self.kemudahan is not None:
+            ws[f"{k}{row}"] = self.kemudahan.value
